"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = exports.langs = void 0;
const ml_config_1 = require("@markuplint/ml-config");
const extRExp = {
    jsx: '\\.[jt]sx?$',
    vue: '\\.vue$',
    svelte: '\\.svelte$',
    astro: '\\.astro$',
    pug: '\\.pug$',
    php: '\\.php$',
    smarty: '\\.tpl$',
    erb: '\\.erb$',
    ejs: '\\.ejs$',
    mustache: '\\.(mustache|hbs)$',
    nunjucks: '\\.nunjucks$',
    liquid: '\\.liquid$',
};
exports.langs = {
    jsx: 'React (JSX)',
    vue: 'Vue',
    svelte: 'Svelte',
    astro: 'Astro',
    pug: 'Pug',
    php: 'PHP',
    smarty: 'Smarty',
    erb: 'eRuby',
    ejs: 'EJS',
    mustache: 'Mustache/Handlebars',
    nunjucks: 'Nunjucks',
    liquid: 'liquid (Shopify)',
};
function createConfig(langs, mode, defaultRules) {
    let config = {};
    for (const lang of langs) {
        config.parser = config.parser || {};
        const ext = extRExp[lang];
        if (!ext) {
            continue;
        }
        config.parser[ext] = `@markuplint/${lang}-parser`;
        if (lang === 'vue') {
            config = (0, ml_config_1.mergeConfig)(config, {
                specs: {
                    '\\.vue$': '@markuplint/vue-spec',
                },
            });
        }
        if (lang === 'jsx') {
            config = (0, ml_config_1.mergeConfig)(config, {
                specs: {
                    '\\.[jt]sx?$': '@markuplint/react-spec',
                },
            });
        }
    }
    if (Array.isArray(mode)) {
        const ruleNames = Object.keys(defaultRules);
        for (const ruleName of ruleNames) {
            const rule = defaultRules[ruleName];
            if (!rule) {
                continue;
            }
            if (mode.includes(rule.category)) {
                if (!config.rules) {
                    config.rules = {};
                }
                config.rules[ruleName] = rule.defaultValue;
            }
        }
    }
    else if (mode === 'recommended') {
        config.extends = [...(config.extends || []), 'markuplint:recommended'];
    }
    else {
        config.rules = {};
        const ruleNames = Object.keys(defaultRules);
        for (const ruleName of ruleNames) {
            const rule = defaultRules[ruleName];
            config.rules[ruleName] = rule.defaultValue;
        }
    }
    return config;
}
exports.createConfig = createConfig;
